@@ -1,12 +1,12 @@
 context("wm_name2id")
 
 test_that("wm_name2id - default usage works", {
-  skip_on_cran()
+  vcr::use_cassette("wm_name2id", {
+    aa <- wm_name2id(name = "Rhincodon")
 
-  aa <- wm_name2id(name = "Rhincodon")
-
-  expect_type(aa, "integer")
-  expect_equal(aa, 105749)
+    expect_type(aa, "integer")
+    expect_equal(aa, 105749)
+  })
 })
 
 test_that("wm_name2id fails well", {
@@ -22,16 +22,18 @@ test_that("wm_name2id fails well", {
 context("wm_name2id_ - plural")
 
 test_that("wm_name2id_ - default usage works", {
-  skip_on_cran()
+  vcr::use_cassette("wm_name2id_", {
+    aa <- wm_name2id_(name = "Rhincodon")
+    expect_type(aa, "list")
+    expect_named(aa, "Rhincodon")
+  })
 
-  aa <- wm_name2id_(name = "Rhincodon")
-  expect_type(aa, "list")
-  expect_named(aa, "Rhincodon")
-
-  bb <- wm_name2id_(name = c("Rhincodon", "Gadus morhua"))
-  expect_type(bb, "list")
-  expect_type(bb[[1]], "integer")
-  expect_named(bb, c("Rhincodon", "Gadus morhua"))
+  vcr::use_cassette("wm_name2id_many", {
+    bb <- wm_name2id_(name = c("Rhincodon", "Gadus morhua"))
+    expect_type(bb, "list")
+    expect_type(bb[[1]], "integer")
+    expect_named(bb, c("Rhincodon", "Gadus morhua"))
+  }, record = "all")
 })
 
 test_that("wm_name2id_ fails well", {
